@@ -20,6 +20,8 @@
 #  25-Jul-2021 jdw refactored with common provider api
 #  27-Jul-2021 jdw add exclusion filter for testing
 #   3-Aug-2021 jdw add backup options for nonbuildable providers
+#  29-Apr-2022 dwp add ModelCacheProvider()
+#  21-Jul-2022  bv Update ModelCacheProvider to make providerType "core" and not stashable or buildable
 ##
 ##
 """
@@ -83,6 +85,9 @@ from rcsb.utils.targets.SAbDabTargetFeatureProvider import SAbDabTargetFeaturePr
 # --
 from rcsb.utils.taxonomy.TaxonomyProvider import TaxonomyProvider
 
+# --
+from rcsb.utils.insilico3d.ModelCacheProvider import ModelCacheProvider
+
 logger = logging.getLogger(__name__)
 
 
@@ -349,6 +354,15 @@ class DictMethodResourceProvider(SingletonClass):
                 "buildable": False,
                 "providerType": "optional_1",
             },
+            "ModelCacheProvider instance": {
+                "class": ModelCacheProvider,
+                "configArgMap": {
+                    "holdingsRemotePath": ("PDBX_COMP_MODEL_CACHE_LIST_PATH", "configPath"),
+                },
+                "stashable": False,
+                "buildable": False,
+                "providerType": "core",
+            },
             # --
         }
         logger.info("Dictionary resource provider restoreUseGit %r restoreUseStash %r providerTypeExclude %r", self.__restoreUseGit, self.__restoreUseStash, self.__providerTypeExclude)
